import * as VueRouter from 'vue-router'

import Landing from "@js/pages/landing.vue";

//Routes
import sellerRoute from "@js/routes/seller_route";
import adminRoute from "@js/routes/admin_route";
import customerRoute from "@js/routes/customer_route";
import deliveryRoute from "@js/routes/delivery_boy_route";
import installationRoute from "@js/routes/installation_route";

export interface IRoute {
    path?: string,
    component?: any,
    name?: string,
    children?: IRoute[];
    redirect?: string; // Add redirect property

}

export function routeGroup(routes: IRoute[], prefix: string, name: string) {
    return routes.map(route => {
        return {
            path: prefix + route.path,
            component: route.component,
            name: route.name != null ? name + "." + route.name : undefined,
            children: route.children != null ? routeGroup(route.children, prefix, name) : undefined
            // name: route.name
        }
    })
}

const otherRoutes: IRoute[] = [{
    path: "/",
    redirect: "/customer" // Automatically redirect to /customer
}, {
    path: "/landing", component: Landing, name: "landing"
},];


const allRoutes = [...adminRoute, ...sellerRoute, ...customerRoute, ...installationRoute, ...deliveryRoute, ...otherRoutes];


export default VueRouter.createRouter({
    history: VueRouter.createWebHistory(),
    scrollBehavior(to, from, savedPosition) {
        if (savedPosition) {
            return savedPosition
        } else {
            return { top: 0 }
        }
    },
    routes: allRoutes
})



